@@ -3,13 +3,12 @@ from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
 
 
-from jijbench.datasets.problem import (
+from jijbench.datasets.problem import (  # get_problem,
     TSP,
     TSPTW,
     BinPacking,
     Knapsack,
     NurseScheduling,
-    # get_problem,
 )
 
 # from jijbench.datasets.instance_data import get_instance_data
